Statistical information about 151 Pokemon from Nintendo RPG series.
pokemonA data frame with 151 observations and 15 variables.
id: Pokedex number.
name: Pokedex name.
height: Height in meters.
weight: Weight in kilograms.
base_experience: How much the Pokemon has battled.
type_1: Primary Pokemon type (i.e. Grass, Fire and Water)
type_2: Secondary Pokemon type (i.e. Poison, Dragon and Ice)
attack: How much damage a Pokemon deals when using a technique.
defense: How much damage a Pokemon receives when it is hit by a technique.
hp: How much damage a Pokemon can receive before fainting.
special_attack: How much damage a Pokemon deals when using a special technique.
special_defense: How much damage a Pokemon receives when it is hit by a special technique.
speed: Determines the order of Pokemon that can act in battle, if the speed is tied then the 1st move is assigned at random.
color_1: Hex color code for Type 1.
color_2: Hex color code for Type 2.